@@ -5,8 +5,15 @@ from logging import DEBUG, INFO, WARN, ERROR, CRITICAL, NOTSET
 
 from automon.integrations.slack.slack_formatting import Emoji, Chat, Format
 
-log = logging.getLogger('logger')
-log.setLevel(CRITICAL)
+logging.getLogger('logger').setLevel(CRITICAL)
+
+TEST = 5
+DEBUG = DEBUG
+INFO = INFO
+WARN = WARN
+ERROR = ERROR
+CRITICAL = CRITICAL
+NOTSET = NOTSET
 
 
 class LogStream(object):
@@ -30,6 +37,7 @@ class Logging:
     """Standard logging to stdout
     """
 
+    TEST = 5
     DEBUG = DEBUG
     INFO = INFO
     WARN = WARN
@@ -38,7 +46,7 @@ class Logging:
     NOTSET = NOTSET
 
     def __init__(self, name: __name__ = __name__, level: logging.INFO = INFO,
-                 log_stream: LogStream = False):
+                 log_stream: LogStream = False, timestamp: bool = True):
 
         self.logging = logging.getLogger(name)
         self.logging.setLevel(level)
@@ -47,16 +55,21 @@ class Logging:
 
         spacing = 4
 
-        timestamp = '%(asctime)s'
+        time = '%(asctime)s'
         levelname = '%(levelname)s'
         logger = '%(name)s'
-        filename = '%(filename)s'
-        pathname = '%(pathname)s'
-        func = '%(funcName)s'
-        line = '%(lineno)d'
-        module = '%(module)s'
+        # filename = '%(filename)s'
+        # pathname = '%(pathname)s'
+        # func = '%(funcName)s'
+        # line = '%(lineno)d'
+        # module = '%(module)s'
         message = '%(message)s'
-        self.log_format = f'{timestamp}\t{levelname}\t[{logger}]\t{message}'
+
+        if timestamp:
+            self.log_format = f'{time}\t{levelname}\t[{logger}]\t{message}'
+        else:
+            self.log_format = f'{levelname}\t[{logger}]\t{message}'
+
         # self.log_format = '%(levelname)s\t%(message)s\t%(name)s'
 
         logging.basicConfig(level=level, format=self.log_format)
@@ -67,9 +80,7 @@ class Logging:
             self.stream = LogStream() if log_stream else None
             logging.basicConfig(level=level, stream=self.stream)
 
-        log.debug('loaded')
-
-    def error(self, msg: str = None, enable_traceback: bool = True):
+    def error(self, msg: any = None, enable_traceback: bool = True):
         tb = traceback.format_exc()
         # tb = Chat.wrap(tb, Format.codeblock)
         if 'NoneType' not in tb and enable_traceback:
@@ -78,19 +89,19 @@ class Logging:
         if msg:
             return self.logging.error(msg)
 
-    def warning(self, msg):
+    def warning(self, msg: any):
         return self.logging.warning(msg)
 
-    def warn(self, msg):
+    def warn(self, msg: any):
         return self.warning(msg)
 
-    def info(self, msg):
+    def info(self, msg: any):
         return self.logging.info(msg)
 
-    def debug(self, msg):
+    def debug(self, msg: any):
         return self.logging.debug(msg)
 
-    def critical(self, msg):
+    def critical(self, msg: any):
         tb = traceback.format_exc()
         tb = Chat.wrap(tb, Format.codeblock)
         if 'NoneType' not in tb:
